@@ -207,6 +207,7 @@ def plot(
                 width = FIGURE_WIDTHS[width]
         if ratio is None:
             ratio = 0.63 if cbar else 0.5
+            if cb_orientation == 'vertical': ratio = 0.5
             if title is not None:
                 # Calculated slope of ratio. Could be better.
                 rat=((0.04 - 0.07)/(7-4.7))*width+0.131
@@ -369,8 +370,10 @@ def plot(
                 cbar_pad =  0.02
                 cbar_shrink =  0.5
 
-        # Remove color bar because of healpy bug
-        plt.gca().collections[-1].colorbar.remove()
+        if plt.gca().collections[-1].colorbar is not None:
+            # Remove color bar because of healpy bug.
+            # Not nessecary after Healpy 1.15.1
+            plt.gca().collections[-1].colorbar.remove()
 
         # Add pretty color bar
         if cbar:
